@@ -3,8 +3,7 @@
 ;; Copyright (C) 2017-2019 Johnson Denen
 ;; Copyright (C) 2021 Abhiseck Paira <abhiseckpaira@disroot.org>
 ;; Author: Johnson Denen <johnson.denen@gmail.com>
-;; Maintainer: Marty Hiatt <martianhiatus@riseup.net>
-;; Version: 1.0.0
+;; Maintainer: Marty Hiatt <mousebot@disroot.org>
 ;; Homepage: https://codeberg.org/martianh/mastodon.el
 
 ;; This file is not part of GNU Emacs.
@@ -175,7 +174,7 @@ Otherwise return nil."
   (let ((username (mastodon-client--form-user-from-vars))
         (user-details (mastodon-client--general-read "active-user")))
     (when (and user-details
-               (equal (plist-get user-details :username) username))
+               (string= (plist-get user-details :username) username))
       user-details)))
 
 (defun mastodon-client--active-user ()
