@@ -151,7 +151,7 @@ Authorization header is included by default unless
 UNAUTHENTICATED-P is non-nil.
 If JSON is :json, encode PARAMS as JSON for
 the request data. If it is :raw, just use the plain params."
-  ;; NB: raw is used by `mastodon-tl--unfilter-user-languages'; not sure if
+  ;; NB: raw is used by `mastodon-tl-unfilter-user-languages'; not sure if
   ;; there's a way around it?
   (mastodon-http--authorized-request "POST"
     (let* ((url-request-data
@@ -315,8 +315,9 @@ JSON means send params as JSON data."
               (encode-coding-string
                (json-encode params) 'utf-8)))
            ;; (mastodon-http--build-params-string params))))
-           (url (unless json
-                  (mastodon-http--concat-params-to-url url params)))
+           (url (if (not json)
+                    (mastodon-http--concat-params-to-url url params)
+                  url))
            (headers (when json
                       '(("Content-Type" . "application/json")
                         ("Accept" . "application/json"))))
